Module person_module

Module person_module 

Main module that contains all useful elements like Person struct, parse func etc

Structs

Person
A struct to contain the information about a person such as name, age,city, zip and phone_number

Enums

MyError
My error type using thiserror to handle error situations

Functions

parse
Main function to parse String object into the Person object(with normalization)
write_to_file
Function to parse content and write it to the file